﻿##############################################################################
# SFX
##############################################################################

init python:
    renpy.music.register_channel("test_one", "sfx", False)
    renpy.music.register_channel("test_two", "sfx", False)
    renpy.music.register_channel("test_three", "sfx", False)
    renpy.music.register_channel("test_four", "sfx", False)
    renpy.music.register_channel("test_five", "sfx", False)
    renpy.music.register_channel("test_six", "sfx", False)
    renpy.music.register_channel("test_seven", "sfx", False)
    renpy.music.register_channel("test_eight", "sfx", False)
    renpy.music.register_channel("test_nine", "sfx", False)
    renpy.music.register_channel("test_ten", "sfx", False)

##############################################################################
# Say
##############################################################################

screen say:

    # Defaults for side_image and two_window
    default side_image = None
    default two_window = False

    # Decide if we want to use the one-window or two-window varaint.
    if not two_window:

        # The one window variant.        
        window:
            id "window"

            has vbox:
                style "say_vbox"

            if who:
                text who id "who"

            text what id "what"

    else:

        # The two window variant.
        vbox:
            style "say_two_window_vbox"

            if who:            
                window:
                    style "say_who_window"

                    text who:
                        id "who"
                        
            window:
                id "window"

                has vbox:
                    style "say_vbox"

                text what id "what"
              
    # If there's a side image, display it above the text.
    if side_image:
        add side_image
    else:
        add SideImage() xalign 0.0 yalign 1.0

    # Use the quick menu.
    use quick_menu
    
init -2 python:
    
    style.say_who_window.background = "gui/name-box.png"
    style.say_who_window.left_padding = 20
    style.say_who_window.right_padding = 10
    style.say_who_window.top_padding = 10
    style.say_who_window.bottom_padding = 2
    style.say_who_window.left_margin = 116
    style.say_who_window.ypos = 60
    
    style.say_label.color = "#1b0502"
    style.say_label.size = 30
    style.say_label.bold = False
    style.say_dialogue.color = "#1b0502"
    style.say_thought.color = "#1b0502"

##############################################################################
# Choice
##############################################################################

screen choice:

    window: 
        style "menu_window"
        xalign 0.5
        yalign 0.5
        
        vbox:
            style "menu"
            spacing 2
            
            for caption, action, chosen in items:
                
                if action:  
                    
                    button:
                        action action
                        style "menu_choice_button"

                        text caption style "menu_choice"
                    
                else:
                    text caption style "menu_caption"

init -2 python:
    config.narrator_menu = True
    
    style.menu_window.set_parent(style.default)
    style.menu_choice.set_parent(style.button_text)
    style.menu_choice.clear()
    style.menu_choice_button.set_parent(style.button)
    style.menu_choice_button.background = "gui/choice-menu.png"
    style.menu_choice_button.hover_background = "gui/choice-menu-hover.png"
    style.menu_choice_button.xminimum = 811
    style.menu_choice_button.xmaximum = 811
    style.menu_choice_button.yminimum = 50
    style.menu_choice_button.ymaximum = 50
    
    style.menu_choice_button.top_padding = 3
    
    style.menu_choice.color = "#1b0502"
    style.menu_choice.hover_color = "#ba5856"

##############################################################################
# Input
##############################################################################

screen input:

    window:
        has vbox

        text prompt
        input id "input"

    use quick_menu
        
##############################################################################
# Main Menu 
##############################################################################

init:
    image first_time = "gui/first-time.png"
    image created_by = "gui/created-by-spaceNote.png"
    
label splashscreen:
    $ renpy.pause(0)
    scene black
    with Pause(0.5)
    
    if not persistent.played:
        show first_time
        with dissolve
        $ renpy.pause(5.0)
    
        $ persistent.played = True
        
        scene black
        with dissolve
        with Pause(0.5)
        
    show created_by
    with dissolve
    with Pause(2.0)    
    play music "music/Frithjof_Brauer_-_Lago_di_Como.mp3" fadein 2 fadeout 2
    
    scene black
    with dissolve
    with Pause(0.5)
    
    return

init python:
    
    import random
    
    random.seed()
    
    #################################################################
    # Snow particles
    # ----------------
    def Snow(image, max_particles=50, speed=150, wind=100, xborder=(0,100), yborder=(50,400), **kwargs):
        """
        This creates the snow effect. You should use this function instead of instancing
        the SnowFactory directly (we'll, doesn't matter actually, but it saves typing if you're
        using the default values =D)
        
        @parm {image} image:
            The image used as the snowflakes. This should always be a image file or an im object,
            since we'll apply im transformations in it.
        
        @parm {int} max_particles:
            The maximum number of particles at once in the screen.
            
        @parm {float} speed:
            The base vertical speed of the particles. The higher the value, the faster particles will fall.
            Values below 1 will be changed to 1
            
        @parm {float} wind:
            The max wind force that'll be applyed to the particles.
            
        @parm {Tuple ({int} min, {int} max)} xborder:
            The horizontal border range. A random value between those two will be applyed when creating particles.
            
        @parm {Tuple ({int} min, {int} max)} yborder:
            The vertical border range. A random value between those two will be applyed when creating particles.
            The higher the values, the fartest from the screen they will be created.
        """
        return Particles(SnowFactory(image, max_particles, speed, wind, xborder, yborder, **kwargs))
    
    # ---------------------------------------------------------------
    class SnowFactory(object):
        """
        The factory that creates the particles we use in the snow effect.
        """
        def __init__(self, image, max_particles, speed, wind, xborder, yborder, **kwargs):
            """
            Initialize the factory. Parameters are the same as the Snow function.
            """            
            self.max_particles = max_particles
            
            self.speed = speed
            
            self.wind = wind
            
            self.xborder = xborder
            self.yborder = yborder
            
            self.depth = kwargs.get("depth", 10)
            
            self.image = self.image_init(image)
            

        def create(self, particles, st):
            """
            This is internally called every frame by the Particles object to create new particles.
            We'll just create new particles if the number of particles on the screen is
            lower than the max number of particles we can have.
            """
            if particles is None or len(particles) < self.max_particles:
                
                depth = random.randint(1, self.depth)
                
                depth_speed = 1.5-depth/(self.depth+0.0)
                
                return [ SnowParticle(self.image[depth-1],      # the image used by the particle 
                                      random.uniform(-self.wind, self.wind)*depth_speed,  # wind's force
                                      self.speed*depth_speed,  # the vertical speed of the particle
                                      random.randint(self.xborder[0], self.xborder[1]), # horizontal border
                                      random.randint(self.yborder[0], self.yborder[1]), # vertical border
                                      ) ]
        
        
        def image_init(self, image):
            """
            This is called internally to initialize the images.
            will create a list of images with different sizes, so we
            can predict them all and use the cached versions to make it more memory efficient.            
            """
            rv = [ ]
            
            for depth in range(self.depth):
                p = 1.1 - depth/(self.depth+0.0)
                if p > 1:
                    p = 1.0
                
                rv.append( im.FactorScale( im.Alpha(image, p), p ) )

            return rv
        
        
        def predict(self):
            """
            This is called internally by the Particles object to predict the images the particles
            are using. It's expected to return a list of images to predict.
            """ 
            return self.image
            
    # ---------------------------------------------------------------
    class SnowParticle(object):
        """
        Represents every particle in the screen.
        """
        def __init__(self, image, wind, speed, xborder, yborder):
            """
            Initializes the snow particle. This is called automatically when the object is created.
            """
            
            self.image = image
            
            if speed <= 0:
                speed = 1
                
            self.wind = wind
            
            self.speed = speed

            self.oldst = None
                      
            self.xpos = random.uniform(0-xborder, renpy.config.screen_width+xborder)
            self.ypos = -yborder
            
            
        def update(self, st):
            """
            Called internally in every frame to update the particle.
            """
            
            # calculate lag
            if self.oldst is None:
                self.oldst = st
            
            lag = st - self.oldst
            self.oldst = st
            
            self.xpos += lag * self.wind
            self.ypos += lag * self.speed
               
            if self.ypos > renpy.config.screen_height or\
               (self.wind< 0 and self.xpos < 0) or (self.wind > 0 and self.xpos > renpy.config.screen_width):
                return None
                
            return int(self.xpos), int(self.ypos), st, self.image
            
screen main_menu:

    tag menu
    
    add "gui/title-screen-back.png"
    
    add Snow("gui/snow.png")
    
    add "gui/title-screen-ground.png"
    
    hbox:
        style_group "firstnav"
        
        xalign 0.493
        yalign 0.903
        
        textbutton _("Start") action Start()
        textbutton _("Load") action ShowMenu("load")
        textbutton _("Pref") action ShowMenu("preferences")
        textbutton _("Extras") action ShowMenu("extras")
        textbutton _("Quit") action Quit(confirm=False)
        
    hbox:
        style_group "secondnav"
        
        xalign 0.503
        yalign 0.973
        
        textbutton _("Help") action Help()
        textbutton _("Official Website") action OpenURL("http://asls.spacenote.net")
        
    add Snow("gui/snow2.png")
    
init -2 python:
    # first nav
    style.firstnav_button.set_parent('default')
    style.firstnav_button.background = None
    style.firstnav_button.xpadding = 14
    style.firstnav_button.hover_sound = "music/beep.mp3"
    
    style.firstnav_button_text.set_parent('default')
    style.firstnav_button_text.size = 70
    style.firstnav_button_text.idle_color = "#ffffff"
    style.firstnav_button_text.hover_color = "#cb8180"
    
    # second nav
    style.secondnav_button.set_parent('default')
    style.secondnav_button.background = None
    style.secondnav_button.xpadding = 8
    #style.secondnav_button.hover_sound = "music/beep.mp3"
    
    style.secondnav_button_text.set_parent('default')
    style.secondnav_button_text.size = 35
    style.secondnav_button_text.idle_color = "#ffffff"
    style.secondnav_button_text.hover_color = "#cb8180"

##############################################################################
# BOTTOM NAVIGATION
##############################################################################

screen bottom_navigation:
    
    add "gui/blank_canvas.png"
    
    imagemap:
        ground "gui/othermenu-ground.png"
        idle "gui/othermenu-idle.png"
        hover "gui/othermenu-hover.png"
        alpha False
       
        hotspot (196, 629, 189, 59) action Return() hovered [Play("test_six", "music/beep.mp3")]
        hotspot (405, 632, 135, 52) action ShowMenu("save") hovered [Play("test_two", "music/beep.mp3")]
        hotspot (558, 630, 141, 56) action ShowMenu("load") hovered [Play("test_one", "music/beep.mp3")]
        hotspot (715, 629, 108, 54) action ShowMenu("preferences") hovered [Play("test_three", "music/beep.mp3")]
        hotspot (842, 627, 114, 56) action MainMenu() hovered [Play("test_five", "music/beep.mp3")]
        hotspot (972, 630, 114, 56) action Quit() hovered [Play("test_four", "music/beep.mp3")]
        
##############################################################################
# Save, Load
##############################################################################
    
screen load_save_slot:
    $ file_text = "%2s. %s\n  %s" % (
                        FileSlotName(number, 4),
                        FileTime(number, empty=_("Empty Slot.")),
                        FileSaveName(number))

    if number == 1:
        add FileScreenshot(number) xpos 253 ypos 40
        add "gui/thumbnail_over.png" xpos 243 ypos 30
        text file_text xpos 40 ypos 36 size 25 color "#1b0502"
        vbox:
            style_group "saveslots"
            
            xpos 40
            ypos 62
            
            textbutton _("(x) Delete") action FileDelete(number , confirm = True)
    elif number == 2:
        add FileScreenshot(number) xpos 257 ypos 40
        add "gui/thumbnail_over.png" xpos 247 ypos 30
        text file_text xpos 40 ypos 36 size 25 color "#1b0502"
        vbox:
            style_group "saveslots"
            
            xpos 40
            ypos 62
            
            textbutton _("(x) Delete") action FileDelete(number , confirm = True)
    elif number == 3:
        add FileScreenshot(number) xpos 45 ypos 53
        add "gui/thumbnail_over.png" xpos 35 ypos 43
        text file_text xpos 330 ypos 48 size 25 color "#1b0502"
        vbox:
            style_group "saveslots"
            
            xpos 330
            ypos 74
            
            textbutton _("(x) Delete") action FileDelete(number , confirm = True)
    else:
        add FileScreenshot(number) xpos 45 ypos 45
        add "gui/thumbnail_over.png" xpos 35 ypos 35
        text file_text xpos 326 ypos 48 size 25 color "#1b0502"
        vbox:
            style_group "saveslots"
            
            xpos 326
            ypos 74
            
            textbutton _("(x) Delete") action FileDelete(number , confirm = True)
   
screen file_picker:
    key "s" action ShowMenu("save")
    key "l" action ShowMenu("load")
    key "w" action FileLoad(1, page="quick", confirm=True, newest=False)
    key "m" action MainMenu(confirm=True)
    key "p" action Return()
    key "K_ESCAPE" action Return()
    
    use bottom_navigation
   
    imagemap:
            ground "gui/load-screen-ground.png"
            idle "gui/load-screen-idle.png"
            hover "gui/load-screen-hover.png"
            selected_idle "gui/load-screen-selected-idle.png"
            selected_hover "gui/load-screen-selected-hover.png"
            alpha False

            if FileCurrentPage() != "1":
                hotspot (299, 549, 226, 49) action [FilePagePrevious(), Play("sound", "music/page-flip.mp3")]
            if FileCurrentPage() != "9":
                hotspot (841, 551, 156, 47) action [FilePageNext(), Play("sound", "music/page-flip.mp3")]
            
            hotspot (537, 550, 25, 50) action [FilePage(1), Play("test_one", "music/page-flip.mp3")]
            hotspot (564, 550, 27, 43) action [FilePage(2), Play("test_two", "music/page-flip.mp3")]
            hotspot (596, 548, 22, 48) action [FilePage(3), Play("test_three", "music/page-flip.mp3")]
            hotspot (627, 548, 27, 48) action [FilePage(4), Play("test_five", "music/page-flip.mp3")]
            hotspot (661, 550, 27, 41) action [FilePage(5), Play("test_six", "music/page-flip.mp3")]
            hotspot (696, 551, 27, 42) action [FilePage(6), Play("test_seven", "music/page-flip.mp3")]
            hotspot (728, 550, 27, 45) action [FilePage(7), Play("test_eight", "music/page-flip.mp3")]
            hotspot (761, 550, 24, 43) action [FilePage(8), Play("test_nine", "music/page-flip.mp3")]
            hotspot (793, 553, 27, 40) action [FilePage(9), Play("test_ten", "music/page-flip.mp3")]

            hotspot (86, 84, 551, 227) clicked [FileAction(1)]:
                use load_save_slot(number=1)
            hotspot (81, 320, 560, 229) clicked [FileAction(2)]:
                use load_save_slot(number=2)
            hotspot (644, 72, 564, 239) clicked [FileAction(3)]:
                use load_save_slot(number=3)
            hotspot (649, 318, 552, 230) clicked [FileAction(4)]:
                use load_save_slot(number=4)
   
screen save:
    key "s" action Return()
    # This ensures that any other menu screen is replaced.
    tag menu

    use file_picker
    add "gui/load-screen-save.png"

screen load:
    key "l" action Return()
    # This ensures that any other menu screen is replaced.
    tag menu

    use file_picker
    add "gui/load-screen-load.png"

init -2 python:
    style.file_picker_frame = Style(style.menu_frame)

    style.file_picker_nav_button = Style(style.small_button)
    style.file_picker_nav_button_text = Style(style.small_button_text)

    style.file_picker_button = Style(style.large_button)
    style.file_picker_text = Style(style.large_button_text)
    config.thumbnail_width = 256
    config.thumbnail_height = 144
    
    style.saveslots_button.set_parent('default')
    style.saveslots_button.background = None
    style.saveslots_button.ypadding = 1
    #style.saveslots_button.hover_sound = "music/beep.mp3"
    
    style.saveslots_button_text.set_parent('default')
    style.saveslots_button_text.size = 17
    style.saveslots_button_text.idle_color = "#970401"
    style.saveslots_button_text.hover_color = "#ba5856"

##############################################################################
# Preferences
##############################################################################

screen volume_controls:
    frame:
        has vbox
        bar value Preference("sound volume")

screen preferences:

    tag menu
    use bottom_navigation

    key "s" action ShowMenu("save")
    key "l" action ShowMenu("load")
    key "w" action FileLoad(1, page="quick", confirm=True, newest=False)
    key "m" action MainMenu(confirm=True)
    key "p" action Return()
    key "K_ESCAPE" action Return()
       
    imagemap:   
        ground "gui/pref-ground.png"
        idle "gui/pref-left-idle.png"
        hover "gui/pref-left-hover.png"
        selected_idle "gui/pref-left-selected-hover.png"
        selected_hover "gui/pref-left-selected.png"
        alpha False
       
        hotspot (409, 139, 135, 38) action Preference("display", "fullscreen")
        hotspot (221, 139, 114, 40) action Preference("display", "window")
        hotspot (129, 322, 210, 40) action Preference("skip", "seen")
        hotspot (370, 322, 177, 43) action Preference("skip", "all")
        hotspot (284, 233, 59, 38) action Preference("transitions", "all")
        hotspot (461, 233, 79, 32) action Preference("transitions", "none")
        hotspot (166, 417, 169, 38) action Preference("after choices", "stop")
        hotspot (360, 417, 193, 47) action Preference("after choices", "skip")
        bar pos (720, 179) value Preference("text speed") style "pref_slider"
        bar pos (720, 301) value Preference("auto-forward time") style "pref_slider" # auto-forward
        bar pos (720, 422) value Preference("music volume") style "pref_slider"
        bar pos (720, 533) value Preference("sound volume") style "pref_slider" # sound vol

init -2 python:
    style.pref_slider.left_bar = "gui/pref-slider.png" #full
    style.pref_slider.right_bar = "gui/pref-slider-empty.png" #empty

    style.pref_slider.xmaximum = 248    # width of your left_bar image.
    style.pref_slider.ymaximum = 24    # height of your left_bar image.  Probably will be the height of the red part of the bar plus the slider's height.

    style.pref_slider.thumb = "gui/pref-thumb.png"
    style.pref_slider.thumb_offset = 6    # Half of your thumb's width in pixels
    style.pref_slider.thumb_shadow = None


##############################################################################
# Yes/No Prompt
##############################################################################
    
screen yesno_prompt:
    modal True
    
    $ somesound = "music/click.mp3"
    
    add "gui/yesno-base.png"
    
    if message == layout.DELETE_SAVE:
        $ somesound = "music/paper-rip.mp3"
    elif message == layout.OVERWRITE_SAVE:
        $ somesound = "music/writing-signature.mp3"
    
    imagebutton auto "gui/yesno-button-yes-%s.png" xpos 430 ypos 270 focus_mask True action [yes_action, Play("sound", somesound)] #hovered [Play("test_one", "music/beep.mp3")]
    imagebutton auto "gui/yesno-button-no-%s.png" xpos 710 ypos 270 focus_mask True action no_action #hovered [Play("test_one", "music/beep.mp3")]
    
    if message == layout.ARE_YOU_SURE:
        add "gui/yesno_are-you-sure.png"
    elif message == layout.DELETE_SAVE:
        add "gui/yesno_delete-save.png"
    elif message == layout.OVERWRITE_SAVE:
        add "gui/yesno_overwrite-save.png"
    elif message == layout.LOADING:
        add "gui/yesno_loading.png"
    elif message == layout.QUIT:
        add "gui/yesno_quit.png"
    elif message == layout.MAIN_MENU:
        add "gui/yesno_main-menu.png"


##############################################################################
# Quick Menu
##############################################################################

screen quick_menu:

    # Add an in-game quick menu.
    hbox:
        style_group "quick"
    
        xalign 0.87
        yalign 0.965

        textbutton _("Q.Save") action QuickSave()
        textbutton _("Q.Load") action QuickLoad()
        textbutton _("Save") action ShowMenu('save')
        textbutton _("Skip") action Skip()
        textbutton _("Auto") action Preference("auto-forward", "toggle")
        textbutton _("Prefs") action ShowMenu('preferences')
        
init -2 python:
    style.quick_button.set_parent('default')
    style.quick_button.background = None
    style.quick_button.xpadding = 5

    style.quick_button_text.set_parent('default')
    style.quick_button_text.size = 17
    style.quick_button_text.idle_color = "#1b0502"
    style.quick_button_text.hover_color = "#ba5856"
    style.quick_button_text.selected_idle_color = "#970401"
    style.quick_button_text.selected_hover_color = "#ba5856"
    style.quick_button_text.insensitive_color = "#cccccc"
    
    # Set a default value for the auto-forward time, and note that AFM is
    # turned off by default.
    config.default_afm_time = 10
    config.default_afm_enable = False
    
##############################################################################
# EXTRAS Navigation
##############################################################################
screen extra_navigation:
    
    add "gui/blank_canvas.png"
    
    imagemap:
        ground "gui/extra-screen-ground.png"
        idle "gui/extra-screen-idle.png"
        hover "gui/extra-screen-hover.png"
        selected_idle "gui/extra-screen-selected-idle.png"
        selected_hover"gui/extra-screen-selected-hover.png"
        alpha False
        
        hotspot (86, 518, 320, 202) action ShowMenu("main_menu") hovered [Play("sound", "music/click.mp3")]
        hotspot (92, 113, 345, 148) action ShowMenu("cg_gallery") hovered [Play("test_two", "music/click.mp3")]
        hotspot (92, 261, 356, 65) action ShowMenu("sketches") hovered [Play("test_three", "music/click.mp3")]
        hotspot (92, 326, 350, 59) action ShowMenu("other_art") hovered [Play("test_four", "music/click.mp3")]
        hotspot (92, 385, 350, 71) action ShowMenu("music_room")  hovered [Play("test_five", "music/click.mp3")]
        hotspot (92, 456, 351, 62) action ShowMenu("credits")  hovered [Play("test_six", "music/click.mp3")]
    
##############################################################################
#EXTRAS SCREEN
##############################################################################

screen extras:
    
    tag menu
    use extra_navigation
    
    add "gui/extra-screen.png"
    
##############################################################################
# CG GALLERY
##############################################################################
init python:
    
    #Galleries settings - start
    gallery_cg_items = ["cg1", "cg2", "cg3"]
    gal_rows = 2
    gal_cols = 3
    thumbnail_x = 256
    thumbnail_y = 144
    #Galleries settings - end
    
    gal_cells = gal_rows * gal_cols    
    g_cg = Gallery()
    for gal_item in gallery_cg_items:
        g_cg.button(gal_item + " butt")
        g_cg.image(gal_item)
        g_cg.unlock(gal_item)
    g_cg.transition = fade
    cg_page=0
    
init +1 python:
    for gal_item in gallery_cg_items:
        renpy.image (gal_item + " butt", im.Scale(ImageReference(gal_item), thumbnail_x, thumbnail_y))
        
screen cg_gallery:
    tag menu
    use extra_navigation
    
    frame background None xpos 540:
        grid gal_rows gal_cols:
            ypos 180
            $ i = 0
            $ next_cg_page = cg_page + 1            
            if next_cg_page > int(len(gallery_cg_items)/gal_cells):
                $ next_cg_page = 0
            for gal_item in gallery_cg_items:
                $ i += 1
                if i <= (cg_page+1)*gal_cells and i>cg_page*gal_cells:
                    add g_cg.make_button(gal_item + " butt", gal_item + " butt", im.Scale("extras/locked.png", thumbnail_x, thumbnail_y), xalign=0.5, yalign=0.5, idle_border=None, background=None, bottom_margin=10)
            for j in range(i, (cg_page+1)*gal_cells): #we need this to fully fill the grid
                null
        frame:
            yalign 0.97
            vbox:
                if len(gallery_cg_items)>gal_cells:
                    textbutton _("Next Page") action [SetVariable('cg_page', next_cg_page), ShowMenu("cg_gallery")]
                    
##############################################################################
# SKETCHES
##############################################################################

init:
    image pr titlescreen = "extras/title-screen-sketch.png"
    image pr ac = "extras/aceline-progress.png"
    image pr em = "extras/emily-progress.png"
    image pr yu = "extras/yuki-progress.png"

init python:
    
    #Galleries settings - start
    gallery_sk_items = ["pr titlescreen", "pr ac", "pr em", "pr yu"]
    #Galleries settings - end
      
    g_sk = Gallery()
    for gal_item in gallery_sk_items:
        g_sk.button(gal_item + " butt")
        g_sk.image(gal_item)
    g_sk.transition = fade
    sk_page=0
    
init +1 python:
    for gal_item in gallery_sk_items:
        renpy.image (gal_item + " butt", im.Scale(ImageReference(gal_item), thumbnail_x, thumbnail_y))
        
screen sketches:
    tag menu
    use extra_navigation
    
    frame background None xpos 520:
        grid gal_rows gal_cols:
            ypos 180
            $ i = 0
            $ next_sk_page = sk_page + 1            
            if next_sk_page > int(len(gallery_sk_items)/gal_cells):
                $ next_sk_page = 0
            for gal_item in gallery_sk_items:
                $ i += 1
                if i <= (sk_page+1)*gal_cells and i>sk_page*gal_cells:
                    add g_sk.make_button(gal_item + " butt", gal_item + " butt", im.Scale("extras/locked.png", thumbnail_x, thumbnail_y), xalign=0.5, yalign=0.5, idle_border=None, background=None, bottom_margin=10)
            for j in range(i, (sk_page+1)*gal_cells): #we need this to fully fill the grid
                null
        frame:
            yalign 0.97
            vbox:
                if len(gallery_sk_items)>gal_cells:
                    textbutton _("Next Page") action [SetVariable('sk_page', next_sk_page), ShowMenu("sketches")]
    
##############################################################################
# Other art
##############################################################################

init:
    image oa1 = "extras/otherart-1.png"
    image oa2 = "extras/otherart-2.png"
    image oa3 = "extras/otherart-3.png"

init python:
    #Galleries settings - start
    gallery_oa_items = ["oa2", "oa3", "oa1"]
    #Galleries settings - end
    
    g_oa = Gallery()
    for gal_item in gallery_oa_items:
        g_oa.button(gal_item + " butt")
        g_oa.image(gal_item)
    g_oa.transition = fade
    oa_page=0
    
init +1 python:
    for gal_item in gallery_oa_items:
        renpy.image (gal_item + " butt", im.Scale(ImageReference(gal_item), thumbnail_x, thumbnail_y))
        
screen other_art:
    tag menu
    use extra_navigation
    
    frame background None xpos 520:
        grid gal_rows gal_cols:
            ypos 180
            $ i = 0
            $ next_oa_page = oa_page + 1            
            if next_oa_page > int(len(gallery_oa_items)/gal_cells):
                $ next_oa_page = 0
            for gal_item in gallery_oa_items:
                $ i += 1
                if i <= (oa_page+1)*gal_cells and i>oa_page*gal_cells:
                    add g_oa.make_button(gal_item + " butt", gal_item + " butt", im.Scale("extras/locked.png", thumbnail_x, thumbnail_y), xalign=0.5, yalign=0.5, idle_border=None, background=None, bottom_margin=10)
            for j in range(i, (oa_page+1)*gal_cells): #we need this to fully fill the grid
                null
        frame:
            yalign 0.97
            vbox:
                if len(gallery_oa_items)>gal_cells:
                    textbutton _("Next Page") action [SetVariable('oa_page', next_oa_page), ShowMenu("other_art")]
    
##############################################################################
# MUSIC ROOM
##############################################################################

init python:

    mr = MusicRoom(fadeout=1.0)

    mr.add("music/Frithjof_Brauer_-_april.mp3", always_unlocked = True)
    mr.add("music/Frithjof_Brauer_-_Lago_di_Como.mp3", always_unlocked=True)
    mr.add("music/Frithjof_Brauer_-_Next_to_you.mp3", always_unlocked=True)
    mr.add("music/Frithjof_Brauer_-_Sometime.mp3", always_unlocked=True)
    mr.add("music/Frithjof_Brauer_-_Terminal_stop_tomorrow.mp3", always_unlocked=True)
    mr.add("music/paolo_di_sabatino_-_Caterina.mp3", always_unlocked=True)
    mr.add("music/paolo_di_sabatino_-_Ninna_nanna.mp3", always_unlocked=True)
    mr.add("music/paolo_di_sabatino_-_Scene_Two.mp3", always_unlocked=True)
    mr.add("music/Paolo_Pavan_-_second__original_soundtrack_.mp3", always_unlocked=True)

screen music_room:

    tag menu
    use extra_navigation

    imagemap:
        
        ground "gui/transparent-ground.png"
        idle "gui/music-box-idle.png"
        hover "gui/music-box-hover.png"
        selected_idle "gui/music-box-selected-idle.png"
        selected_hover "gui/music-box-selected-hover.png"
        alpha False
        
        hotspot (622, 200, 338, 48) action mr.Play("music/Frithjof_Brauer_-_april.mp3") #1 lago
        hotspot (460, 250, 465, 45) action mr.Play("music/Frithjof_Brauer_-_Lago_di_Como.mp3") #1 lago
        hotspot (625, 302, 433, 43) action mr.Play("music/Frithjof_Brauer_-_Next_to_you.mp3") #2 next
        hotspot (510, 348, 407, 46) action mr.Play("music/Frithjof_Brauer_-_Sometime.mp3") #3 some
        hotspot (632, 400, 591, 45) action mr.Play("music/Frithjof_Brauer_-_Terminal_stop_tomorrow.mp3") #4 termi
        hotspot (555, 450, 362, 44) action mr.Play("music/Paolo_Pavan_-_second__original_soundtrack_.mp3") #5 secon
        hotspot (632, 502, 438, 43) action mr.Play("music/paolo_di_sabatino_-_Caterina.mp3") #6 cater
        hotspot (429, 548, 488, 44) action mr.Play("music/paolo_di_sabatino_-_Ninna_nanna.mp3") #6 cater
        hotspot (629, 594, 473, 43) action mr.Play("music/paolo_di_sabatino_-_Scene_Two.mp3") #7 scen
    
    on "replace" action mr.Play()
    
##############################################################################
# CREDITS
##############################################################################

screen credits:
    tag menu
    use extra_navigation
    
    add "gui/credits.png"
    
##############################################################################
# OPEN WEBSITE
##############################################################################

init python:
    import webbrowser
    
label launch_website:
    $ web_browser.open("http://asls.spacenote.net/")
